@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -42,7 +43,7 @@ class NUZFBRequest(NURESTObject):
     """ Represents a ZFBRequest in the VSD
 
         Notes:
-            A ZFB Request from an NSG
+            Pending requests reflect Network Services Gateways that have initiated request for bootstrapping. Requests can be assigned or matched to continue the bootstrapping process
     """
 
     __rest_name__ = "zfbrequest"
@@ -63,6 +64,10 @@ class NUZFBRequest(NURESTObject):
     
     CONST_ZFB_APPROVAL_STATUS_ASSIGNED = "ASSIGNED"
     
+    CONST_ASSOCIATED_ENTITY_TYPE_GATEWAY = "GATEWAY"
+    
+    CONST_ASSOCIATED_ENTITY_TYPE_NSGATEWAY = "NSGATEWAY"
+    
     
 
     def __init__(self, **kwargs):
@@ -95,11 +100,15 @@ class NUZFBRequest(NURESTObject):
         self._family = None
         self._last_connected_time = None
         self._last_updated_by = None
+        self._registration_url = None
         self._serial_number = None
         self._entity_scope = None
         self._hostname = None
         self._associated_enterprise_id = None
         self._associated_enterprise_name = None
+        self._associated_entity_type = None
+        self._associated_gateway_id = None
+        self._associated_gateway_name = None
         self._associated_ns_gateway_id = None
         self._associated_ns_gateway_name = None
         self._status_string = None
@@ -118,11 +127,15 @@ class NUZFBRequest(NURESTObject):
         self.expose_attribute(local_name="family", remote_name="family", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_connected_time", remote_name="lastConnectedTime", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="registration_url", remote_name="registrationURL", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="serial_number", remote_name="serialNumber", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="hostname", remote_name="hostname", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_enterprise_id", remote_name="associatedEnterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_enterprise_name", remote_name="associatedEnterpriseName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_entity_type", remote_name="associatedEntityType", attribute_type=str, is_required=False, is_unique=False, choices=[u'GATEWAY', u'NSGATEWAY'])
+        self.expose_attribute(local_name="associated_gateway_id", remote_name="associatedGatewayID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_gateway_name", remote_name="associatedGatewayName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ns_gateway_id", remote_name="associatedNSGatewayID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_ns_gateway_name", remote_name="associatedNSGatewayName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status_string", remote_name="statusString", attribute_type=str, is_required=False, is_unique=False)
@@ -258,7 +271,7 @@ class NUZFBRequest(NURESTObject):
         """ Get zfb_request_retry_timer value.
 
             Notes:
-                ZFB Request retry timer on NSG. Set from System Config
+                ZFB Request retry timer on the gateway. Set on VSD's System Config panel.
 
                 
                 This attribute is named `ZFBRequestRetryTimer` in VSD API.
@@ -271,7 +284,7 @@ class NUZFBRequest(NURESTObject):
         """ Set zfb_request_retry_timer value.
 
             Notes:
-                ZFB Request retry timer on NSG. Set from System Config
+                ZFB Request retry timer on the gateway. Set on VSD's System Config panel.
 
                 
                 This attribute is named `ZFBRequestRetryTimer` in VSD API.
@@ -285,7 +298,7 @@ class NUZFBRequest(NURESTObject):
         """ Get sku value.
 
             Notes:
-                The part number of the NSG
+                The part number of the gateway being bootstrapped through ZFB.
 
                 
                 This attribute is named `SKU` in VSD API.
@@ -298,7 +311,7 @@ class NUZFBRequest(NURESTObject):
         """ Set sku value.
 
             Notes:
-                The part number of the NSG
+                The part number of the gateway being bootstrapped through ZFB.
 
                 
                 This attribute is named `SKU` in VSD API.
@@ -312,7 +325,7 @@ class NUZFBRequest(NURESTObject):
         """ Get ip_address value.
 
             Notes:
-                IP Address of the NSG
+                IP Address of the gateway being bootstrapped using ZFB.
 
                 
                 This attribute is named `IPAddress` in VSD API.
@@ -325,7 +338,7 @@ class NUZFBRequest(NURESTObject):
         """ Set ip_address value.
 
             Notes:
-                IP Address of the NSG
+                IP Address of the gateway being bootstrapped using ZFB.
 
                 
                 This attribute is named `IPAddress` in VSD API.
@@ -420,7 +433,7 @@ class NUZFBRequest(NURESTObject):
         """ Get family value.
 
             Notes:
-                NSG Type
+                Gateway Type
 
                 
         """
@@ -431,7 +444,7 @@ class NUZFBRequest(NURESTObject):
         """ Set family value.
 
             Notes:
-                NSG Type
+                Gateway Type
 
                 
         """
@@ -443,7 +456,7 @@ class NUZFBRequest(NURESTObject):
         """ Get last_connected_time value.
 
             Notes:
-                the time in which the last GET was made from the NSG
+                The time in which the last GET was made from the gateway.
 
                 
                 This attribute is named `lastConnectedTime` in VSD API.
@@ -456,7 +469,7 @@ class NUZFBRequest(NURESTObject):
         """ Set last_connected_time value.
 
             Notes:
-                the time in which the last GET was made from the NSG
+                The time in which the last GET was made from the gateway.
 
                 
                 This attribute is named `lastConnectedTime` in VSD API.
@@ -492,12 +505,39 @@ class NUZFBRequest(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def registration_url(self):
+        """ Get registration_url value.
+
+            Notes:
+                Registration URL to be used for a gateway to be bootstrapped using ZFB.
+
+                
+                This attribute is named `registrationURL` in VSD API.
+                
+        """
+        return self._registration_url
+
+    @registration_url.setter
+    def registration_url(self, value):
+        """ Set registration_url value.
+
+            Notes:
+                Registration URL to be used for a gateway to be bootstrapped using ZFB.
+
+                
+                This attribute is named `registrationURL` in VSD API.
+                
+        """
+        self._registration_url = value
+
+    
     @property
     def serial_number(self):
         """ Get serial_number value.
 
             Notes:
-                The NSG's Serial Number
+                The gateway's Serial Number.
 
                 
                 This attribute is named `serialNumber` in VSD API.
@@ -510,7 +550,7 @@ class NUZFBRequest(NURESTObject):
         """ Set serial_number value.
 
             Notes:
-                The NSG's Serial Number
+                The gateway's Serial Number.
 
                 
                 This attribute is named `serialNumber` in VSD API.
@@ -551,7 +591,7 @@ class NUZFBRequest(NURESTObject):
         """ Get hostname value.
 
             Notes:
-                hostname of the NSG
+                Hostname of the gateway bootstrapped using ZFB.
 
                 
         """
@@ -562,7 +602,7 @@ class NUZFBRequest(NURESTObject):
         """ Set hostname value.
 
             Notes:
-                hostname of the NSG
+                Hostname of the gateway bootstrapped using ZFB.
 
                 
         """
@@ -601,7 +641,7 @@ class NUZFBRequest(NURESTObject):
         """ Get associated_enterprise_name value.
 
             Notes:
-                name of the associated Enterprise
+                Name of the associated enterprise
 
                 
                 This attribute is named `associatedEnterpriseName` in VSD API.
@@ -614,7 +654,7 @@ class NUZFBRequest(NURESTObject):
         """ Set associated_enterprise_name value.
 
             Notes:
-                name of the associated Enterprise
+                Name of the associated enterprise
 
                 
                 This attribute is named `associatedEnterpriseName` in VSD API.
@@ -623,6 +663,87 @@ class NUZFBRequest(NURESTObject):
         self._associated_enterprise_name = value
 
     
+    @property
+    def associated_entity_type(self):
+        """ Get associated_entity_type value.
+
+            Notes:
+                Associated Entity Type: NSGATEWAY or GATEWAY
+
+                
+                This attribute is named `associatedEntityType` in VSD API.
+                
+        """
+        return self._associated_entity_type
+
+    @associated_entity_type.setter
+    def associated_entity_type(self, value):
+        """ Set associated_entity_type value.
+
+            Notes:
+                Associated Entity Type: NSGATEWAY or GATEWAY
+
+                
+                This attribute is named `associatedEntityType` in VSD API.
+                
+        """
+        self._associated_entity_type = value
+
+    
+    @property
+    def associated_gateway_id(self):
+        """ Get associated_gateway_id value.
+
+            Notes:
+                ID of the assigned Gateway
+
+                
+                This attribute is named `associatedGatewayID` in VSD API.
+                
+        """
+        return self._associated_gateway_id
+
+    @associated_gateway_id.setter
+    def associated_gateway_id(self, value):
+        """ Set associated_gateway_id value.
+
+            Notes:
+                ID of the assigned Gateway
+
+                
+                This attribute is named `associatedGatewayID` in VSD API.
+                
+        """
+        self._associated_gateway_id = value
+
+    
+    @property
+    def associated_gateway_name(self):
+        """ Get associated_gateway_name value.
+
+            Notes:
+                Name of the associated Gateway
+
+                
+                This attribute is named `associatedGatewayName` in VSD API.
+                
+        """
+        return self._associated_gateway_name
+
+    @associated_gateway_name.setter
+    def associated_gateway_name(self, value):
+        """ Set associated_gateway_name value.
+
+            Notes:
+                Name of the associated Gateway
+
+                
+                This attribute is named `associatedGatewayName` in VSD API.
+                
+        """
+        self._associated_gateway_name = value
+
+    
     @property
     def associated_ns_gateway_id(self):
         """ Get associated_ns_gateway_id value.
@@ -655,7 +776,7 @@ class NUZFBRequest(NURESTObject):
         """ Get associated_ns_gateway_name value.
 
             Notes:
-                name of the associated NSG
+                Name of the associated NSG
 
                 
                 This attribute is named `associatedNSGatewayName` in VSD API.
@@ -668,7 +789,7 @@ class NUZFBRequest(NURESTObject):
         """ Set associated_ns_gateway_name value.
 
             Notes:
-                name of the associated NSG
+                Name of the associated NSG
 
                 
                 This attribute is named `associatedNSGatewayName` in VSD API.
